@@ -1,7 +1,6 @@
 from time import sleep
-from serial import Serial
+import serial
 from serial.tools.list_ports import comports
-from serial import tools
 from . import kb_config
 
 ser = None
@@ -28,7 +27,7 @@ def initialize_connection():
     global ser
     try:
         print(f'Forbinder til micro:bit på: {kb_config.tty_name}')
-        ser = Serial(kb_config.tty_name, kb_config.tty_rate, timeout=kb_config.tty_timeout)
+        ser = serial.Serial(kb_config.tty_name, kb_config.tty_rate, timeout=kb_config.tty_timeout)
         ser.reset_input_buffer()
         ser.reset_output_buffer()
         sleep(0.2)
